@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,6 @@
  *
 */
 
-
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
@@ -27,34 +25,25 @@
 #include "create_disc_tab.h"
 #include "populate_disc_tab.h"
 
-
 /* Wether or not to let the disc section expand */
 #define EXPAND_DISC_SECTION TRUE
 
-
-
 void create_disc_tab(struct w *widgets)
 {
     GtkCellRenderer *disc_cell_renderer;
     GtkWidget *disc_treeview_hbox;
     GtkWidget *disc_scrolled_window;
-    gchar *utf8=NULL;
-
-    GtkTooltips *tooltips;
-    tooltips = gtk_tooltips_new();
+    gchar *utf8 = NULL;
 
     /* Create the disc treeview in a scrolled window */
     disc_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox4), disc_treeview_hbox, EXPAND_DISC_SECTION, TRUE, 0);
 
-    disc_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    disc_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(disc_treeview_hbox), disc_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(disc_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(disc_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
-    widgets->disc_store = gtk_list_store_new(6, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, 
-    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    widgets->disc_store = gtk_list_store_new(6, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->disc_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->disc_treeview), GTK_TREE_MODEL(widgets->disc_store));
@@ -90,11 +79,10 @@ void create_disc_tab(struct w *widgets)
 
     GtkWidget *update_disc_button = gtk_button_new_from_stock(GTK_STOCK_REFRESH);
     gtk_box_pack_start(GTK_BOX(disc_button_box), update_disc_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(update_disc_button), "clicked",
-                             G_CALLBACK(populate_discs), widgets);
+    g_signal_connect_swapped(G_OBJECT(update_disc_button), "clicked", G_CALLBACK(populate_discs), widgets);
 
     gtk_widget_show_all(widgets->main_window);
 
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 }
