@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "gettext.h"
 #include "widgets.h"
 #include "allocate.h"
+#include "show_info.h"
 #include "functions.h"
 #include "import_functions.h"
 #include "create_import_window.h"
@@ -38,7 +39,6 @@
 extern gchar *GP_PASSWD_BUF;
 
 
-
 void create_import_window(struct w *widgets)
 {
     /* Create and populate the import window */
@@ -48,7 +48,7 @@ void create_import_window(struct w *widgets)
     char *old_buffer, *new_buffer;
     GtkTreeIter iter;
     GtkTreeSelection *selection;
-    gchar *utf8=NULL;
+    gchar *utf8 = NULL;
     gchar *username, *groupname;
     GtkTreeViewColumn *user_col, *group_col;
     GtkCellRenderer *import_cell_renderer;
@@ -74,9 +74,19 @@ void create_import_window(struct w *widgets)
     GtkWidget *hbox3;
     GtkWidget *image2;
     GtkWidget *label3;
-    GtkTooltips *tooltips;
+    gint active_index = 0;
+    gchar *info;
 
-    tooltips = gtk_tooltips_new();
+    /* We dont import database users yet */
+    active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[8]));
+    if( active_index > 1  )
+    {
+        info = g_strdup_printf(
+            _("Importing users from a database is not supported yet.\n"));
+        show_info(info);
+        g_free(info);
+        return;
+    }
 
     widgets->import_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_widget_set_size_request(widgets->import_window, 560, 350);
@@ -99,7 +109,7 @@ void create_import_window(struct w *widgets)
     gtk_container_add(GTK_CONTAINER(import_scrolledwindow), widgets->import_treeview);
     gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(widgets->import_treeview), TRUE);
 
-    widgets->import_store = gtk_list_store_new(2, G_TYPE_STRING , G_TYPE_STRING);
+    widgets->import_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->import_treeview), GTK_TREE_MODEL(widgets->import_store));
 
     /* Set the column labels in the treeview */
@@ -135,6 +145,7 @@ void create_import_window(struct w *widgets)
     widgets->import_home_entry = gtk_entry_new();
     gtk_box_pack_start(GTK_BOX(import_hbox1), widgets->import_home_entry, TRUE, TRUE, 20);
     gtk_entry_set_text(GTK_ENTRY(widgets->import_home_entry), "/var/ftp");
+    // FIX: Get this from settings.conf
 
     import_hbox3 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(import_vbox), import_hbox3, FALSE, FALSE, 0);
@@ -174,7 +185,7 @@ void create_import_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbox2), image1, FALSE, FALSE, 0);
 
     label2 = gtk_label_new_with_mnemonic(_("Import"));
-    gtk_box_pack_start(GTK_BOX (hbox2), label2, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox2), label2, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label2), GTK_JUSTIFY_LEFT);
 
     import_cancel_button = gtk_button_new();
@@ -194,18 +205,12 @@ void create_import_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbox3), label3, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label3), GTK_JUSTIFY_LEFT);
 
-//    g_signal_connect((gpointer)widgets->import_namebased_checkbutton, "toggled",
-//                	    G_CALLBACK(import_namebased_checkbutton_toggled), widgets);
 
-//    g_signal_connect((gpointer)widgets->import_upload_checkbutton, "toggled",
-//                	    G_CALLBACK(import_upload_checkbutton_toggled), widgets);
-		    
-    g_signal_connect((gpointer)import_button, "clicked",
-                	    G_CALLBACK(import_button_clicked), widgets);
-		    
-    g_signal_connect_swapped((gpointer)import_cancel_button, "clicked",
-                    	    G_CALLBACK(gtk_widget_destroy),
-                            GTK_OBJECT(widgets->import_window));
+    g_signal_connect((gpointer) import_button,
+            "clicked", G_CALLBACK(import_button_clicked), widgets);
+
+    g_signal_connect_swapped((gpointer) import_cancel_button,
+            "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(widgets->import_window));
 
     gtk_widget_show_all(widgets->import_window);
 
@@ -213,55 +218,55 @@ void create_import_window(struct w *widgets)
 
     /* Populate the import treeview with users */
 
-    if((fp=fopen(GP_PASSWD_BUF, "r"))==NULL)
+    if((fp = fopen(GP_PASSWD_BUF, "r")) == NULL)
     {
-	printf("Cant open passwd here:\n%s\n", GP_PASSWD_BUF);
-	return;
+        printf("Cant open passwd here:\n%s\n", GP_PASSWD_BUF);
+        return;
     }
 
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(conf_size);          
-    new_buffer = allocate(8192);          
+    old_buffer = allocate(conf_size);
+    new_buffer = allocate(8192);
 
-    while(fgets(old_buffer, conf_size, fp)!=NULL) 
+    while(fgets(old_buffer, conf_size, fp) != NULL)
     {
-	if( strlen(old_buffer) > 10 && strlen(old_buffer) < 4000 )
-	{
-	    for(i=0; old_buffer[i]!='\0'; i++)
-	      if( old_buffer[i]==':' )
-		break;
+        if( strlen(old_buffer) > 10 && strlen(old_buffer) < 4000 )
+        {
+            for(i = 0; old_buffer[i] != '\0'; i++)
+                if( old_buffer[i] == ':' )
+                    break;
 
-	    strcpy(new_buffer, old_buffer);
-	    new_buffer[i]='\0';
-		
-	    /* Dont insert root or the user the server runs as */
-	    if( !strcmp(new_buffer, "root") || !strcmp(new_buffer, SERVER_USER) )
-	      continue;
+            strcpy(new_buffer, old_buffer);
+            new_buffer[i] = '\0';
 
-		
-	    gtk_list_store_append(GTK_LIST_STORE(widgets->import_store), &iter);
+            /* Dont insert root or the user the server runs as */
+            if( ! strcmp(new_buffer, "root") || ! strcmp(new_buffer, SERVER_USER) )
+                continue;
 
-	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
-	    gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 0, utf8, -1);
 
-	    /* Get this users groupname */
-	    username = g_strdup_printf("%s", new_buffer);
-	    groupname = get_user_setting(username, "group");
-	    snprintf(new_buffer, 4000, "%s", groupname);
-	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
-	    gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 1, utf8, -1);
-	    g_free(username);
-	    g_free(groupname);
-	}
+            gtk_list_store_append(GTK_LIST_STORE(widgets->import_store), &iter);
+
+            utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 0, utf8, -1);
+
+            /* Get this users groupname */
+            username = g_strdup_printf("%s", new_buffer);
+            groupname = get_user_setting(username, "group");
+            snprintf(new_buffer, 4000, "%s", groupname);
+            utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+            gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 1, utf8, -1);
+            g_free(username);
+            g_free(groupname);
+        }
     }
     fclose(fp);
 
     free(old_buffer);
     free(new_buffer);
-    
+
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 }
