@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,16 +45,15 @@ void create_server_tab(struct w *widgets)
     GtkWidget *server_treeview_hbox, *settings_treeview_hbox;
     GtkWidget *server_scrolled_window;
     GtkWidget *frame;
-    gchar *utf8=NULL;
+    gchar *utf8 = NULL;
 
     GtkWidget *import_alignment;
     GtkWidget *import_hbox;
     GtkWidget *import_image;
     GtkWidget *import_label;
 
-
-    GtkTooltips *tooltips;
-    tooltips = gtk_tooltips_new();
+//    GtkTooltips *tooltips;
+//    tooltips = gtk_tooltips_new();
 
 
     /* Create the domain treeview in a scrolled window */
@@ -63,9 +62,7 @@ void create_server_tab(struct w *widgets)
 
     server_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(server_treeview_hbox), server_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(server_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(server_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(server_scrolled_window, -1, 100);
 
@@ -92,8 +89,7 @@ void create_server_tab(struct w *widgets)
     GtkTreeViewColumn *server_type_col = gtk_tree_view_column_new_with_attributes(_("Server type"), server_cell_renderer, "text", 3, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_VIEW_COLUMN(server_type_col));
 
-    g_signal_connect((gpointer)widgets->server_treeview, "button_press_event",
-		      G_CALLBACK(server_treeview_row_clicked), widgets);
+    g_signal_connect((gpointer) widgets->server_treeview, "button_press_event", G_CALLBACK(server_treeview_row_clicked), widgets);
 
 
     /* The import, add, delete and change server entries and buttons */
@@ -107,43 +103,39 @@ void create_server_tab(struct w *widgets)
     GtkWidget *import_users_button = gtk_button_new();
     gtk_box_pack_start(GTK_BOX(server_button_box), import_users_button, FALSE, FALSE, 0);
 
-    import_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
-    gtk_widget_show (import_alignment);
+    import_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
+    gtk_widget_show(import_alignment);
     gtk_container_add(GTK_CONTAINER(import_users_button), import_alignment);
 
-    import_hbox = gtk_hbox_new (FALSE, 2);
-    gtk_widget_show (import_hbox);
+    import_hbox = gtk_hbox_new(FALSE, 2);
+    gtk_widget_show(import_hbox);
     gtk_container_add(GTK_CONTAINER(import_alignment), import_hbox);
 
     import_image = gtk_image_new_from_stock("gtk-convert", GTK_ICON_SIZE_BUTTON);
-    gtk_widget_show (import_image);
+    gtk_widget_show(import_image);
     gtk_box_pack_start(GTK_BOX(import_hbox), import_image, FALSE, FALSE, 0);
 
     import_label = gtk_label_new_with_mnemonic(_("Import"));
-    gtk_widget_show (import_label);
+    gtk_widget_show(import_label);
     gtk_box_pack_start(GTK_BOX(import_hbox), import_label, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label), GTK_JUSTIFY_LEFT);
-    g_signal_connect_swapped(G_OBJECT(import_users_button), "clicked", 
-                             G_CALLBACK(create_import_window), widgets);
+    g_signal_connect_swapped(G_OBJECT(import_users_button), "clicked", G_CALLBACK(create_import_window), widgets);
 
 
     /* The delete server button */
     GtkWidget *delete_server_button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
     gtk_box_pack_start(GTK_BOX(server_button_box), delete_server_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(delete_server_button), "clicked", 
-                             G_CALLBACK(delete_server), widgets);
+    g_signal_connect_swapped(G_OBJECT(delete_server_button), "clicked", G_CALLBACK(delete_server), widgets);
 
     /* The add server button */
     GtkWidget *add_server_button = gtk_button_new_from_stock(GTK_STOCK_ADD);
     gtk_box_pack_start(GTK_BOX(server_button_box), add_server_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(add_server_button), "clicked", 
-                             G_CALLBACK(add_server), widgets);
+    g_signal_connect_swapped(G_OBJECT(add_server_button), "clicked", G_CALLBACK(add_server), widgets);
 
     /* The Apply server button */
     GtkWidget *apply_server_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
     gtk_box_pack_start(GTK_BOX(server_button_box), apply_server_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(apply_server_button), "clicked", 
-                             G_CALLBACK(apply_server_settings), widgets);
+    g_signal_connect_swapped(G_OBJECT(apply_server_button), "clicked", G_CALLBACK(apply_server_settings), widgets);
 
 
 
@@ -151,11 +143,9 @@ void create_server_tab(struct w *widgets)
     settings_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox1), settings_treeview_hbox, EXPAND_SERVER_SETTINGS_SECTION, TRUE, 0);
 
-    widgets->server_settings_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    widgets->server_settings_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(settings_treeview_hbox), widgets->server_settings_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->server_settings_scrolled_window), 
-						    GTK_POLICY_NEVER,
-						    GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->server_settings_scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(widgets->server_settings_scrolled_window, -1, 100);
@@ -168,7 +158,7 @@ void create_server_tab(struct w *widgets)
     frame = gtk_frame_new(_("Settings"));
 
     /* Add a table with for the settings with 3 columns */
-    widgets->srv_set_table = gtk_table_new(NUM_SERVERTAB_ENTRIES+NUM_SERVERTAB_SPINBUTTONS+NUM_SERVERTAB_COMBOS, 3, FALSE);
+    widgets->srv_set_table = gtk_table_new(NUM_SERVERTAB_ENTRIES + NUM_SERVERTAB_SPINBUTTONS + NUM_SERVERTAB_COMBOS, 3, FALSE);
     gtk_box_pack_start(GTK_BOX(widgets->server_settings_vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), widgets->srv_set_table);
 
@@ -176,5 +166,5 @@ void create_server_tab(struct w *widgets)
     gtk_widget_show_all(widgets->main_window);
 
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 }
