@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 
 #define EXPAND_TRANSFER_SECTION 1
 
-void transfer_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event, struct w *widgets)
+void transfer_treeview_row_clicked(GtkTreeView * treeview, GdkEventButton * event, struct w *widgets)
 {
     gchar *pid, *username;
     GtkTreeIter iter;
@@ -40,34 +40,33 @@ void transfer_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
 
     /* The left button is pressed */
     if( ! event->type == GDK_BUTTON_PRESS || ! event->button == 1 )
-      return;
+        return;
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 
     if( gtk_tree_selection_count_selected_rows(selection) <= 1 )
     {
-	 /* Get the treepath for the row that was clicked */
-         if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y,
-				                                &path, NULL, NULL, NULL))
-         {
+        /* Get the treepath for the row that was clicked */
+        if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y, &path, NULL, NULL, NULL) )
+        {
             gtk_tree_selection_unselect_all(selection);
-    	    gtk_tree_selection_select_path(selection, path);
+            gtk_tree_selection_select_path(selection, path);
 
-	    list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-	    gtk_tree_model_get_iter(list_store, &iter, path);
-	    gtk_tree_model_get(list_store, &iter, 0, &pid, -1);
-	    gtk_tree_model_get(list_store, &iter, 1, &username, -1);
+            list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+            gtk_tree_model_get_iter(list_store, &iter, path);
+            gtk_tree_model_get(list_store, &iter, 0, &pid, -1);
+            gtk_tree_model_get(list_store, &iter, 1, &username, -1);
 
-	    /* Insert pid or username */
-	    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->transfer_pid_checkbutton)) )
-	      gtk_entry_set_text(GTK_ENTRY(widgets->kick_entry), pid);
-	    else
-	      gtk_entry_set_text(GTK_ENTRY(widgets->kick_entry), username);
+            /* Insert pid or username */
+            if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->transfer_pid_checkbutton)) )
+                gtk_entry_set_text(GTK_ENTRY(widgets->kick_entry), pid);
+            else
+                gtk_entry_set_text(GTK_ENTRY(widgets->kick_entry), username);
 
-	    g_free(pid);
-	    g_free(username);
+            g_free(pid);
+            g_free(username);
             gtk_tree_path_free(path);
-    	 }
+        }
     }
 }
 
@@ -79,8 +78,8 @@ void create_transfer_tab(struct w *widgets)
     GtkWidget *transfer_scrolled_window;
     gchar *utf8 = NULL;
 
-    GtkTooltips *tooltips;
-    tooltips = gtk_tooltips_new();
+//    GtkTooltips *tooltips;
+//    tooltips = gtk_tooltips_new();
 
     /* Create the transfer treeview in a scrolled window */
     transfer_treeview_hbox = gtk_hbox_new(TRUE, 0);
@@ -89,11 +88,10 @@ void create_transfer_tab(struct w *widgets)
     transfer_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(transfer_treeview_hbox), transfer_scrolled_window, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(transfer_scrolled_window),
-						    GTK_POLICY_AUTOMATIC,
-						    GTK_POLICY_ALWAYS);
+                                            GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
-    widgets->transfer_store = gtk_list_store_new(8, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, 
-    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    widgets->transfer_store = gtk_list_store_new(8, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->transfer_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->transfer_treeview), GTK_TREE_MODEL(widgets->transfer_store));
@@ -129,8 +127,8 @@ void create_transfer_tab(struct w *widgets)
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->transfer_treeview), GTK_TREE_VIEW_COLUMN(server_col));
 
     /* Treeview clicked callback */
-    g_signal_connect((gpointer)widgets->transfer_treeview, "button_press_event",
-	        		G_CALLBACK(transfer_treeview_row_clicked), widgets);
+    g_signal_connect((gpointer) widgets->transfer_treeview,
+            "button_press_event", G_CALLBACK(transfer_treeview_row_clicked), widgets);
 
 
     /* Add a speed hbox */
@@ -139,8 +137,8 @@ void create_transfer_tab(struct w *widgets)
 
     /* Transfer speed labels. Text and speeds are added in status_update. */
     widgets->total_bandwidth_label = gtk_label_new("");
-    widgets->total_incoming_label  = gtk_label_new("");
-    widgets->total_outgoing_label  = gtk_label_new("");
+    widgets->total_incoming_label = gtk_label_new("");
+    widgets->total_outgoing_label = gtk_label_new("");
 
     gtk_box_pack_start(GTK_BOX(speed_hbox), widgets->total_bandwidth_label, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(speed_hbox), widgets->total_incoming_label, FALSE, FALSE, 0);
@@ -186,8 +184,7 @@ void create_transfer_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(kick_label), GTK_JUSTIFY_LEFT);
 
     gtk_box_pack_start(GTK_BOX(transfer_button_box), kick_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(GTK_OBJECT(kick_button), "clicked",
-			     G_CALLBACK(kick_button_clicked), widgets);
+    g_signal_connect_swapped(GTK_OBJECT(kick_button), "clicked", G_CALLBACK(kick_button_clicked), widgets);
 
     GtkWidget *kickban_button = gtk_button_new();
     GtkWidget *kickban_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
@@ -206,11 +203,10 @@ void create_transfer_tab(struct w *widgets)
 
     gtk_box_pack_start(GTK_BOX(transfer_button_box), kickban_button, FALSE, FALSE, 0);
 
-    g_signal_connect_swapped(GTK_OBJECT(kickban_button), "clicked",
-			     G_CALLBACK(kick_ban_button_clicked), widgets);
+    g_signal_connect_swapped(GTK_OBJECT(kickban_button), "clicked", G_CALLBACK(kick_ban_button_clicked), widgets);
 
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     gtk_widget_show_all(widgets->main_window);
 }
