@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,17 +28,13 @@
 #include "create_user_tab.h"
 #include "user_treeview_row_clicked.h"
 #include "populate_shell_combo.h"
-#include "apply_user.h"
 #include "file_chooser.h"
 
 #define EXPAND_USER_SECTION FALSE
 #define EXPAND_USER_SETTINGS_SECTION TRUE
 
 
-void directory_cell_edited(GtkCellRendererText *cell,
-			   gchar *path_string,
-			   gchar *new_text,
-			   struct w *widgets)
+void directory_cell_edited(GtkCellRendererText * cell, gchar * path_string, gchar * new_text, struct w *widgets)
 {
     /* Changes the edited directory cell text */
     GtkTreeIter iter;
@@ -47,8 +43,8 @@ void directory_cell_edited(GtkCellRendererText *cell,
     path = gtk_tree_path_new_from_string(path_string);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, path);
 
-    if( path!=NULL )
-      gtk_tree_path_free(path);
+    if( path != NULL )
+        gtk_tree_path_free(path);
 
     gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 0, new_text, -1);
 }
@@ -60,27 +56,26 @@ void dir_toggle_button_clicked(GtkCellRendererToggle *cell, gchar *path, struct
     gboolean val;
     GtkTreeModel *model;
     GtkTreePath *treepath = NULL;
-    int column = (int) g_object_get_data(G_OBJECT(cell), "column");
-			    
+    int column = (int)g_object_get_data(G_OBJECT(cell), "column");
+
     treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
     gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, column, &val, -1);
     if( val )
-	gtk_list_store_set(widgets->directory_store, &iter, column, FALSE, -1);
+        gtk_list_store_set(widgets->directory_store, &iter, column, FALSE, -1);
     else
-	gtk_list_store_set(widgets->directory_store, &iter, column, TRUE, -1);
+        gtk_list_store_set(widgets->directory_store, &iter, column, TRUE, -1);
 
     gtk_tree_path_free(treepath);
 }
 
 
-void add_directory(gchar *dir, struct w *widgets)
+void add_directory(gchar * dir, struct w *widgets)
 {
     /* Adds a directory with default permissions to the directory treeview */
     int i = 0;
-    GtkTreeModel *model;
     GtkTreeIter iter;
     gchar *utf8 = NULL;
     gchar *dir_path;
@@ -91,16 +86,17 @@ void add_directory(gchar *dir, struct w *widgets)
     gtk_list_store_set(widgets->directory_store, &iter, 0, utf8, -1);
     g_free(dir_path);
 
-    /* Select a few default permissions for the directory */
-    model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
-    for(i=1; i<19; i++)
+    /* Select a few safe default permissions for the directory */
+    for(i = 1; i < 19; i++)
     {
-	if( i==1 || i == 4 || i > 13 )
-	  gtk_list_store_set(widgets->directory_store, &iter, i, TRUE, -1);
+        if( i == 1 || i == 4 || i > 13 )
+            gtk_list_store_set(widgets->directory_store, &iter, i, TRUE, -1);
     }
-    
-    if( utf8!=NULL )
-      g_free(utf8);
+
+    if( utf8 != NULL )
+        g_free(utf8);
+
+   /* The user needs to press apply. Dont do it automatically */
 }
 
 
@@ -109,9 +105,9 @@ void select_directory_clicked(struct w *widgets)
     gchar *path = NULL;
 
     path = get_dialog_path_selection("DIR", "/var/ftp", "None");
-    if( path!=NULL )
+    if( path != NULL )
     {
-	add_directory(path, widgets);
+        add_directory(path, widgets);
         g_free(path);
     }
 }
@@ -119,7 +115,7 @@ void select_directory_clicked(struct w *widgets)
 
 void del_directory(struct w *widgets)
 {
-    /* Deletes the selected directory if its not 
+    /* Deletes the selected directory if its not
        the one listed first (the home/root directory) */
     GtkTreeSelection *selection;
     GtkTreeModel *model;
@@ -138,9 +134,11 @@ void del_directory(struct w *widgets)
 
     /* A row is selected and its not the first one, remove it */
     if( val && has_row_above )
-      gtk_list_store_remove(widgets->directory_store, &iter);
-      
+        gtk_list_store_remove(widgets->directory_store, &iter);
+
     gtk_tree_path_free(path);
+
+   /* The user needs to press apply. Dont do it automatically */
 }
 
 
@@ -163,15 +161,14 @@ void create_user_tab(struct w *widgets)
     user_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), user_treeview_hbox, EXPAND_USER_SECTION, TRUE, 0);
 
-    user_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    user_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(user_treeview_hbox), user_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(user_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(user_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(user_scrolled_window, -1, 100);
 
-    widgets->user_store = gtk_list_store_new(7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    widgets->user_store = gtk_list_store_new(7,
+        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->user_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_MODEL(widgets->user_store));
@@ -182,29 +179,36 @@ void create_user_tab(struct w *widgets)
     /* Set the column labels in the treeview */
     user_cell_renderer = gtk_cell_renderer_text_new();
 
-    GtkTreeViewColumn *user_col = gtk_tree_view_column_new_with_attributes(_("User"), user_cell_renderer, "text", 0, NULL);
+    GtkTreeViewColumn *user_col = gtk_tree_view_column_new_with_attributes(
+                _("User"), user_cell_renderer, "text", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(user_col));
 
-    GtkTreeViewColumn *group_col = gtk_tree_view_column_new_with_attributes(_("Group"), user_cell_renderer, "text", 1, NULL);
+    GtkTreeViewColumn *group_col = gtk_tree_view_column_new_with_attributes(
+                _("Group"), user_cell_renderer, "text", 1, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(group_col));
 
-    GtkTreeViewColumn *comment_col = gtk_tree_view_column_new_with_attributes(_("Comment"), user_cell_renderer, "text", 2, NULL);
+    GtkTreeViewColumn *comment_col = gtk_tree_view_column_new_with_attributes(
+                _("Comment"), user_cell_renderer, "text", 2, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(comment_col));
 
-    GtkTreeViewColumn *homedir_col = gtk_tree_view_column_new_with_attributes(_("Home directory"), user_cell_renderer, "text", 3, NULL);
+    GtkTreeViewColumn *homedir_col = gtk_tree_view_column_new_with_attributes(
+                _("Home directory"), user_cell_renderer, "text", 3, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(homedir_col));
 
-    GtkTreeViewColumn *req_password_col = gtk_tree_view_column_new_with_attributes(_("Require password"), user_cell_renderer, "text", 4, NULL);
+    GtkTreeViewColumn *req_password_col = gtk_tree_view_column_new_with_attributes(
+                _("Require password"), user_cell_renderer, "text", 4, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(req_password_col));
 
-    GtkTreeViewColumn *banned_col = gtk_tree_view_column_new_with_attributes(_("Banned"), user_cell_renderer, "text", 5, NULL);
+    GtkTreeViewColumn *banned_col = gtk_tree_view_column_new_with_attributes(
+                _("Banned"), user_cell_renderer, "text", 5, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(banned_col));
 
-    GtkTreeViewColumn *max_logins_col = gtk_tree_view_column_new_with_attributes(_("Maximum connections"), user_cell_renderer, "text", 6, NULL);
+    GtkTreeViewColumn *max_logins_col = gtk_tree_view_column_new_with_attributes(
+                _("Maximum connections"), user_cell_renderer, "text", 6, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->user_treeview), GTK_TREE_VIEW_COLUMN(max_logins_col));
 
-    g_signal_connect((gpointer)widgets->user_treeview, "button_press_event",  
-		      G_CALLBACK(user_treeview_row_clicked), widgets);
+    g_signal_connect((gpointer) widgets->user_treeview,
+                "button_press_event", G_CALLBACK(user_treeview_row_clicked), widgets);
 
 
     /* The delete, new user and apply buttonbox */
@@ -215,45 +219,47 @@ void create_user_tab(struct w *widgets)
 
     /* Create the user settings scrolled window with a frame and a table */
     user_settings_treeview_hbox = gtk_hbox_new(TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), user_settings_treeview_hbox, EXPAND_USER_SETTINGS_SECTION, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2),
+        user_settings_treeview_hbox, EXPAND_USER_SETTINGS_SECTION, TRUE, 0);
 
-    widgets->user_settings_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(user_settings_treeview_hbox), widgets->user_settings_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    widgets->user_settings_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+    gtk_box_pack_start(GTK_BOX(user_settings_treeview_hbox),
+                widgets->user_settings_scrolled_window, TRUE, TRUE, 0);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window),
+                                                        GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(widgets->user_settings_scrolled_window, -1, 100);
 
     /* Add a vbox to the scrolled window */
     widgets->user_settings_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window), widgets->user_settings_vbox);
+    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window),
+                        widgets->user_settings_vbox);
 
     /* Add a frame */
     frame = gtk_frame_new(_("User settings and directories:"));
 
     /* A table with NUM settings and 2 columns */
-    widgets->usr_set_table = gtk_table_new(NUM_USERTAB_ENTRIES+NUM_USERTAB_SPINBUTTONS+NUM_USERTAB_CHECKBUTTONS+NUM_USERTAB_COMBOS, 2, FALSE);
+    widgets->usr_set_table =
+        gtk_table_new(NUM_USERTAB_ENTRIES + NUM_USERTAB_SPINBUTTONS + NUM_USERTAB_CHECKBUTTONS + NUM_USERTAB_COMBOS, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), widgets->usr_set_table);
 
 
     /* Create the directory treeview in the user settings scrolled window */
-    directory_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    directory_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), directory_scrolled_window, FALSE, FALSE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(directory_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(directory_scrolled_window),
+                                            GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(directory_scrolled_window, -1, 100);
 
 
     /* Directory store with some columns... */
-    widgets->directory_store = gtk_list_store_new(19, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
-    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
-    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
-    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
-    
+    widgets->directory_store = gtk_list_store_new(19, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+        G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+        G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
+        G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+
     /* Create the directory treeeview and add it to the scrolled window */
     widgets->directory_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_MODEL(widgets->directory_store));
@@ -283,8 +289,8 @@ void create_user_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(label230), GTK_JUSTIFY_LEFT);
 
     /* The add directory signal hookup */
-    g_signal_connect_swapped(add_directory_button, "clicked",
-                    	     G_CALLBACK(select_directory_clicked), widgets);
+    g_signal_connect_swapped(add_directory_button,
+                "clicked", G_CALLBACK(select_directory_clicked), widgets);
 
     /* Spacer label */
     GtkWidget *label910 = gtk_label_new("");
@@ -295,7 +301,8 @@ void create_user_tab(struct w *widgets)
     /* Delete directory button */
     GtkWidget *del_directory_button = gtk_button_new();
     gtk_box_pack_start(GTK_BOX(add_dir_hbox), del_directory_button, FALSE, FALSE, 0);
-    gtk_tooltips_set_tip(tooltips, del_directory_button, _("Delete the selected directory."), NULL);
+    gtk_tooltips_set_tip(tooltips, del_directory_button,
+                _("Delete the selected directory."), NULL);
 
     GtkWidget *alignment64 = gtk_alignment_new(0.5, 0.5, 0, 0);
     gtk_container_add(GTK_CONTAINER(del_directory_button), alignment64);
@@ -310,8 +317,7 @@ void create_user_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(label234), GTK_JUSTIFY_LEFT);
 
     /* The delete directory signal hookup */
-    g_signal_connect_swapped(del_directory_button, "clicked",
-                    	     G_CALLBACK(del_directory), widgets);
+    g_signal_connect_swapped(del_directory_button, "clicked", G_CALLBACK(del_directory), widgets);
 
 
     /* Spacer label */
@@ -320,128 +326,124 @@ void create_user_tab(struct w *widgets)
     gtk_widget_set_size_request(label340, 20, -1);
     gtk_label_set_justify(GTK_LABEL(label340), GTK_JUSTIFY_LEFT);
 
-    /* A second apply button does the same as the one in the user frame */
-/*
-    GtkWidget *apply_directory_button = gtk_button_new();
-    gtk_box_pack_start(GTK_BOX(add_dir_hbox), apply_directory_button, FALSE, FALSE, 0);
-    gtk_tooltips_set_tip(tooltips, apply_directory_button, _("Apply changes after adding directories and setting permissions."), NULL);
-
-    GtkWidget *alignment68 = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_container_add(GTK_CONTAINER(apply_directory_button), alignment68);
-
-    GtkWidget *hbox68 = gtk_hbox_new(FALSE, 2);
-    gtk_container_add(GTK_CONTAINER(alignment68), hbox68);
-    GtkWidget *image58 = gtk_image_new_from_stock("gtk-refresh", GTK_ICON_SIZE_BUTTON);
-    gtk_box_pack_start(GTK_BOX(hbox68), image58, FALSE, FALSE, 0);
-
-    GtkWidget *label238 = gtk_label_new_with_mnemonic(_("Apply changes"));
-    gtk_box_pack_start(GTK_BOX(hbox68), label238, FALSE, FALSE, 0);
-    gtk_label_set_justify(GTK_LABEL(label238), GTK_JUSTIFY_LEFT);
-*/
-    /* The second apply buttons signal hookup */
-//    g_signal_connect_swapped(apply_directory_button, "clicked",
-//                    	     G_CALLBACK(apply_user), widgets);
 
     /* Make the directory cell editable */
     dir_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(dir_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(dir_cell_renderer, "edited",  
-		      G_CALLBACK(directory_cell_edited), widgets);
+    g_signal_connect(dir_cell_renderer, "edited", G_CALLBACK(directory_cell_edited), widgets);
 
     /* Add callbacks for the toggle buttons and set data on the cells to column numbers */
-    for(i=0; i < 19; i++)
+    for(i = 0; i < 19; i++)
     {
-	toggle_cell_renderer[i] = gtk_cell_renderer_toggle_new();
-	g_object_set(toggle_cell_renderer[i], "activatable", TRUE, NULL);
+        toggle_cell_renderer[i] = gtk_cell_renderer_toggle_new();
+        g_object_set(toggle_cell_renderer[i], "activatable", TRUE, NULL);
 
-	g_object_set_data(G_OBJECT(toggle_cell_renderer[i]), "column", (void*)(i+1));
+        g_object_set_data(G_OBJECT(toggle_cell_renderer[i]), "column", (void *)(i + 1));
 
-	g_signal_connect(toggle_cell_renderer[i], "toggled",
-		      G_CALLBACK(dir_toggle_button_clicked), widgets);
+        g_signal_connect(toggle_cell_renderer[i],
+                "toggled", G_CALLBACK(dir_toggle_button_clicked), widgets);
     }
 
-    colnr  = 0;
+    colnr = 0;
     cellnr = 0;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Directory"), dir_cell_renderer, "text", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; /* Separate dir cell */
+    colnr++;                    /* Separate dir cell */
 
     /* Limit commands, begins at colnr 1 and cells at 0 */
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("List"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Upload"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Append"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Download"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Rename"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Overwrite"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Delete"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Make directory"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Remove directory"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Site"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Chmod"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Change group"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Show dates"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Show working directory"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Show sizes"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Stat"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Change working directory"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("CD up"), toggle_cell_renderer[cellnr], "active", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
-    colnr++; cellnr++;
+    colnr++;
+    cellnr++;
 
     gtk_widget_show_all(widgets->main_window);
 
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 }
