@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 extern struct w *widgets;
 
 int cmplowercase(char *buf, char *cmpstring);
+int chars_are_digits(char *buf);
+int commented(char *line);
 
 gchar *get_user_setting(gchar *user, gchar *what);
 
