@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,13 +23,10 @@
 #include "make_settings_entries.h"
 
 
-GtkWidget *make_entry_with_label(GtkTable *table,
-                                 const gchar *label_text,
-                                 gint left_attach,
-                                 gint right_attach,
-                                 gint top_attach,
-                                 gint bottom_attach,
-                                 gint entry_length)
+GtkWidget * make_entry_with_label(GtkTable * table,
+                        const gchar * label_text, gint left_attach,
+                                gint right_attach, gint top_attach,
+                              gint bottom_attach, gint entry_length)
 {
     GtkWidget *entry;
     GtkWidget *label;
@@ -37,7 +34,8 @@ GtkWidget *make_entry_with_label(GtkTable *table,
     label = gtk_label_new(label_text);
     entry = gtk_entry_new();
     gtk_table_attach(table, label, left_attach, right_attach, top_attach, bottom_attach, GTK_FILL, GTK_EXPAND, 2, 2);
-    gtk_table_attach(table, entry, left_attach + 1, right_attach + 1, top_attach, bottom_attach, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 20, 2);
+    gtk_table_attach(table, entry, left_attach + 1, right_attach + 1, top_attach, bottom_attach,
+                                             GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 20, 2);
 
     gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
     gtk_misc_set_padding(GTK_MISC(label), 2, 2);
@@ -46,17 +44,14 @@ GtkWidget *make_entry_with_label(GtkTable *table,
 
     gtk_widget_show(entry);
     gtk_widget_show(label);
- 
+
     return entry;
 }
 
-GtkWidget *make_long_entry_with_label(GtkTable *table,
-                                 const gchar *label_text,
-                                 gint left_attach,
-                                 gint right_attach,
-                                 gint top_attach,
-                                 gint bottom_attach,
-                                 gint entry_length)
+GtkWidget * make_long_entry_with_label(GtkTable * table,
+                            const gchar * label_text, gint left_attach,
+                                    gint right_attach, gint top_attach,
+                                  gint bottom_attach, gint entry_length)
 {
     GtkWidget *entry;
     GtkWidget *label;
@@ -64,7 +59,8 @@ GtkWidget *make_long_entry_with_label(GtkTable *table,
     label = gtk_label_new(label_text);
     entry = gtk_entry_new();
     gtk_table_attach(table, label, left_attach, right_attach, top_attach, bottom_attach, GTK_FILL, GTK_EXPAND, 2, 2);
-    gtk_table_attach(table, entry, left_attach + 1, right_attach + 2, top_attach, bottom_attach, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 20, 2);
+    gtk_table_attach(table, entry, left_attach + 1, right_attach + 2, top_attach, bottom_attach,
+                                             GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 20, 2);
 
     gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
     gtk_misc_set_padding(GTK_MISC(label), 2, 2);
@@ -73,6 +69,6 @@ GtkWidget *make_long_entry_with_label(GtkTable *table,
 
     gtk_widget_show(entry);
     gtk_widget_show(label);
- 
+
     return entry;
 }
