@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,16 +23,14 @@
 #include "make_settings_labels.h"
 
 
-void make_3columns_label(GtkTable *table,
-                                 const gchar *label_text,
-                                 gint left_attach,
-                                 gint right_attach,
-                                 gint top_attach,
-                                 gint bottom_attach)
+void make_3columns_label(GtkTable * table, const gchar * label_text,
+                           gint left_attach, gint right_attach,
+                            gint top_attach, gint bottom_attach)
 {
     GtkWidget *label;
 
     label = gtk_label_new(label_text);
-    gtk_table_attach(table, label, left_attach, right_attach + 3, top_attach, bottom_attach, GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(table, label, left_attach, right_attach + 3, top_attach, bottom_attach,
+                                                                  GTK_FILL, GTK_EXPAND, 5, 5);
     gtk_widget_show(label);
 }
