@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,11 +31,8 @@
 #include "populate_disc_tab.h"
 #include "show_info.h"
 
-
-// Hmm,,, this is an extern!!!!!
 #define MAX_READ_POPEN 16384
 
-
 #define DISC_USAGE "df -hP | grep /"
 
 
@@ -45,24 +42,25 @@ void populate_discs(struct w *widgets)
     FILE *fp;
     GtkTreeIter iter;
     GtkTreePath *path;
-    gboolean edit=0;
+    gboolean edit = 0;
     int found = 0;
-    gchar *utf8=NULL;
-
-    char buf[MAX_READ_POPEN]="";
-    char mount[8192]="", free[1024]="", used[1024]="", total[1024]="", percent[1024]="", device[8192]="";
+    gchar *utf8 = NULL;
+    char buf[MAX_READ_POPEN] = "";
+    char mount[8192] = "", free[1024] = "";
+    char used[1024] = "", total[1024] = "";
+    char percent[1024] = "", device[8192] = "";
 
     gtk_list_store_clear(widgets->disc_store);
 
 
-    if((fp=popen(DISC_USAGE, "r"))==NULL)
+    if((fp = popen(DISC_USAGE, "r")) == NULL)
     {
         printf("Error running command %s\n", DISC_USAGE);
         return;
     }
     fflush(fp);
 
-    while(fgets(buf, MAX_READ_POPEN, fp)!=NULL)
+    while(fgets(buf, MAX_READ_POPEN, fp) != NULL)
     {
         sscanf(buf, "%s %s %s %s %s %s", device, total, used, free, percent, mount);
 
@@ -86,16 +84,16 @@ void populate_discs(struct w *widgets)
         utf8 = g_locale_to_utf8(device, strlen(device), NULL, NULL, NULL);
         gtk_list_store_set(GTK_LIST_STORE(widgets->disc_store), &iter, 5, utf8, -1);
 
-	found = 1;
+        found = 1;
     }
     pclose(fp);
-   
-    if(utf8 !=NULL)
-      g_free(utf8);
+
+    if( utf8 != NULL )
+        g_free(utf8);
 
     /* Cant set treepath if there arent any discs/rows, then itll crash */
     if( ! found )
-      return;
+        return;
 
     path = gtk_tree_path_new_first();
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(widgets->disc_treeview), path, NULL, edit);
