@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,31 +44,32 @@
 
 void populate_gadmin_proftpd(struct w *widgets)
 {
-	/* Populate the servers treeview */
-	populate_servers(widgets);
-	/* Set the first server as selected */
-	select_first_server(widgets);
+    /* Populate the servers treeview */
+    populate_servers(widgets);
+    /* Set the first server as selected */
+    select_first_server(widgets);
 
-	/* Populate the server settings */
-	populate_server_settings(widgets);
+    /* Populate the server settings */
+    populate_server_settings(widgets);
 
-	/* Populate the user tab */
-	populate_users(widgets);   
-	/* Set the first user as selected */
-	select_first_user(widgets);
+    /* Populate the user tab */
+    populate_users(widgets);
+    /* Set the first user as selected */
+    select_first_user(widgets);
 
-	/* Populate the user settings */
-	populate_user_settings(widgets);
+    /* Populate the user settings */
+    populate_user_settings(widgets);
 
-	/* Populate the disc tab */
-	populate_discs(widgets);
+    /* Populate the disc tab */
+    populate_discs(widgets);
 
-	/* Populate the file tab */
-	/* This can take a long time so we let the user do this manually  populate_files(widgets); */
+    /* Populate the file tab */
+    /* This can take a long time so we let the user do this manually
+       populate_files(widgets); */
 
-	/* Populate the security tab */
-	populate_security(widgets);
+    /* Populate the security tab */
+    populate_security(widgets);
 
-	/* Populate the conf tab */
-	populate_conf_tab(widgets);
+    /* Populate the conf tab */
+    populate_conf_tab(widgets);
 }
