@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 */
 
 
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -32,22 +31,21 @@
 extern int activated;
 
 
-
 void reread_conf(struct w *widgets)
 {
     /* Reread with a HUP and show any errors */
-    gchar *command, *test;
+    gchar *cmd, *test;
 
     if( ! activated )
-      return;
+        return;
 
-    command = g_strdup_printf("killall -1 %s", PROFTPD_BINARY);
-    if( ! run_command(command) )
+    cmd = g_strdup_printf("killall -HUP %s", PROFTPD_BINARY);
+    if( ! run_command(cmd) )
     {
         printf("Restarting proftpd failed\n");
-        test = g_strdup_printf("killall -1 %s 2>&1", PROFTPD_BINARY);
-	run_command_show_err(test);
-	g_free(test);
+        test = g_strdup_printf("killall -HUP %s 2>&1", PROFTPD_BINARY);
+        run_command_show_err(test);
+        g_free(test);
     }
-    g_free(command);
+    g_free(cmd);
 }
