@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,8 +37,7 @@ extern char global_server_type[1024];
 
 
 
-void server_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
-								gpointer data)
+void server_treeview_row_clicked(GtkTreeView * treeview, GdkEventButton * event, gpointer data)
 {
     gchar *address, *port, *type;
     GtkTreeIter iter;
@@ -47,39 +46,38 @@ void server_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
     GtkTreeSelection *selection;
 
     /* The left button is pressed */
-    if( ! event->type == GDK_BUTTON_PRESS || ! event->button == 1 )
-      return;
+    if( ! event->type == GDK_BUTTON_PRESS || !event->button == 1 )
+        return;
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 
     if( gtk_tree_selection_count_selected_rows(selection) <= 1 )
     {
-	/* Get the treepath for the row that was clicked */
-         if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y,
-				                                &path, NULL, NULL, NULL))
-         {
+        /* Get the treepath for the row that was clicked */
+        if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y, &path, NULL, NULL, NULL) )
+        {
             gtk_tree_selection_unselect_all(selection);
-    	    gtk_tree_selection_select_path(selection, path);
+            gtk_tree_selection_select_path(selection, path);
 
-	    list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-	    gtk_tree_model_get_iter(list_store, &iter, path);
-	    gtk_tree_model_get(list_store, &iter, 0, &address, -1);
-	    gtk_tree_model_get(list_store, &iter, 1, &port, -1);
-	    gtk_tree_model_get(list_store, &iter, 3, &type, -1);
+            list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+            gtk_tree_model_get_iter(list_store, &iter, path);
+            gtk_tree_model_get(list_store, &iter, 0, &address, -1);
+            gtk_tree_model_get(list_store, &iter, 1, &port, -1);
+            gtk_tree_model_get(list_store, &iter, 3, &type, -1);
 
-	    sprintf(global_server_address, "%s", address?address:"None");
-	    sprintf(global_server_port, "%s", port?port:"21");
-	    sprintf(global_server_type, "%s", type?type:"None");
+            sprintf(global_server_address, "%s", address ? address : "None");
+            sprintf(global_server_port, "%s", port ? port : "21");
+            sprintf(global_server_type, "%s", type ? type : "None");
 
-	    g_free(address);
-	    g_free(port);
-	    g_free(type);
+            g_free(address);
+            g_free(port);
+            g_free(type);
             gtk_tree_path_free(path);
 
-	    populate_server_settings(data);
-	    populate_users(data);
-	    select_first_user(data);
-	    populate_user_settings(data);
-    	 }
+            populate_server_settings(data);
+            populate_users(data);
+            select_first_user(data);
+            populate_user_settings(data);
+        }
     }
 }
