@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 extern int info_window_exit_main;
 
 
-void info_set_exit(gchar *content)
+void info_set_exit(gchar * content)
 {
     /* 2 means break the non-root wait loop in main() */
     info_window_exit_main = 2;
@@ -36,44 +36,38 @@ void info_set_exit(gchar *content)
 
 
 
-void show_info(gchar *content)
+void show_info(gchar * content)
 {
-    gchar *utf8=NULL;
+    gchar *utf8 = NULL;
     GtkTextBuffer *text_buffer;
     gchar *info;
     GtkWidget *info_window, *info_vbox, *info_textview;
     GtkWidget *info_viewport, *scrolled_info_window;
 
-    if( content == NULL )
+    if( content == NULL || strlen(content) < 5 )
     {
-       printf("show_info recieved null content\n");
-       return;
-    }
-    
-    if( strlen(content) < 5 )
-    {
-       printf("show_info recieved < 5 chars of content\n");
-       return;
+        printf("show_info recieved less then 5 chars of content\n");
+        return;
     }
 
     info_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_widget_set_size_request(info_window, 630, 350);
-    gtk_window_set_position(GTK_WINDOW (info_window), GTK_WIN_POS_CENTER);
-    
+    gtk_window_set_position(GTK_WINDOW(info_window), GTK_WIN_POS_CENTER);
+
     /* Set window information */
     info = g_strdup_printf(_("GADMIN-PROFTPD %s Information"), VERSION);
     gtk_window_set_title(GTK_WINDOW(info_window), info);
     g_free(info);
 
     info_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (info_window), info_vbox);
+    gtk_container_add(GTK_CONTAINER(info_window), info_vbox);
 
     /* Put a scrolled window in the vbox */
-    scrolled_info_window = gtk_scrolled_window_new (NULL, NULL);
+    scrolled_info_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(info_vbox), scrolled_info_window, TRUE, TRUE, 0);
 
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_info_window), 
-				      GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_info_window),
+                                        GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
     info_viewport = gtk_viewport_new(NULL, NULL);
     gtk_container_add(GTK_CONTAINER(scrolled_info_window), info_viewport);
@@ -81,7 +75,6 @@ void show_info(gchar *content)
     info_textview = gtk_text_view_new();
     gtk_container_add(GTK_CONTAINER(info_viewport), info_textview);
 
-//FIXME add GTK_TEXT_VIEW to the other apps also
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(info_textview), GTK_WRAP_WORD);
 
 
@@ -92,29 +85,29 @@ void show_info(gchar *content)
     /* Used with main() and closing the non-root timer */
     if( info_window_exit_main )
     {
-	g_signal_connect_swapped((gpointer) close_info_button, "clicked",
-                         G_CALLBACK(info_set_exit), info_window);
+        g_signal_connect_swapped((gpointer) close_info_button,
+                "clicked", G_CALLBACK(info_set_exit), info_window);
 
-	g_signal_connect(GTK_WINDOW(info_window), "delete_event", 
-                         GTK_SIGNAL_FUNC(info_set_exit), info_window);
+        g_signal_connect(GTK_WINDOW(info_window),
+                "delete_event", GTK_SIGNAL_FUNC(info_set_exit), info_window);
     }
 
     /* Regular close info window hookups */
     if( ! info_window_exit_main )
     {
-	g_signal_connect_swapped((gpointer) close_info_button, "clicked",
-                              G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(info_window));
+        g_signal_connect_swapped((gpointer) close_info_button,
+                "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(info_window));
 
-	g_signal_connect(GTK_WINDOW(info_window), "delete_event", 
-		     G_CALLBACK(gtk_widget_destroy), NULL);
+        g_signal_connect(GTK_WINDOW(info_window),
+                "delete_event", G_CALLBACK(gtk_widget_destroy), NULL);
     }
 
 
     text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(info_textview));
     utf8 = g_locale_to_utf8(content, strlen(content), NULL, NULL, NULL);
-    if( utf8!=NULL )
+    if( utf8 != NULL )
     {
-	/* Strlen error on NULL, thats why.. */
+        /* Strlen error on NULL, thats why.. */
         gtk_text_buffer_set_text(text_buffer, utf8, strlen(utf8));
         g_free(utf8);
     }
