@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2013 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,7 @@ extern char global_user_name[1024];
 
 
 
-void user_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
-								gpointer data)
+void user_treeview_row_clicked(GtkTreeView * treeview, GdkEventButton * event, gpointer data)
 {
     gchar *user;
     GtkTreeIter iter;
@@ -41,29 +40,28 @@ void user_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
 
     /* The left button is pressed */
     if( ! event->type == GDK_BUTTON_PRESS || ! event->button == 1 )
-      return;
+        return;
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 
     if( gtk_tree_selection_count_selected_rows(selection) <= 1 )
     {
-	/* Get the treepath for the row that was clicked */
-         if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y,
-				                                &path, NULL, NULL, NULL))
-         {
+        /* Get the treepath for the row that was clicked */
+        if( gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y, &path, NULL, NULL, NULL) )
+        {
             gtk_tree_selection_unselect_all(selection);
-    	    gtk_tree_selection_select_path(selection, path);
+            gtk_tree_selection_select_path(selection, path);
 
-	    list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-	    gtk_tree_model_get_iter(list_store, &iter, path);
-	    gtk_tree_model_get(list_store, &iter, 0, &user, -1);
+            list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+            gtk_tree_model_get_iter(list_store, &iter, path);
+            gtk_tree_model_get(list_store, &iter, 0, &user, -1);
 
-	    sprintf(global_user_name, "%s", (gchar *)user?user:"None");
+            sprintf(global_user_name, "%s", (gchar *) user ? user : "None");
 
-	    g_free(user);
+            g_free(user);
             gtk_tree_path_free(path);
 
-	    populate_user_settings(data);
-    	 }
+            populate_user_settings(data);
+        }
     }
 }
